enum InternetPipeCapabilities
{
	IPC_ENCRYPTED=1,
	IPC_COMPRESSED=2,
	IPC_COMPRESSED_ZSTD = 4,
};